@@ -17,6 +17,9 @@
 #include <torrent/utils/log.h>
 #include <torrent/utils/option_strings.h>
 
+#include "globals.h"
+#include "control.h"
+#include "command_helpers.h"
 #include "core/download.h"
 #include "core/manager.h"
 #include "rpc/scgi.h"
@@ -24,10 +27,6 @@
 #include "rpc/parse.h"
 #include "rpc/parse_commands.h"
 
-#include "globals.h"
-#include "control.h"
-#include "command_helpers.h"
-
 torrent::Object
 apply_encryption(const torrent::Object::list_type& args) {
   uint32_t options_mask = torrent::net::NetworkConfig::encryption_none;
@@ -79,7 +78,7 @@ initialize_rpc_handlers() {
 
 torrent::Object
 apply_scgi(const std::string& arg, int type) {
-  if (worker_thread->scgi() != NULL)
+  if (scgi_thread::scgi() != nullptr)
     throw torrent::input_error("SCGI already enabled.");
 
   initialize_rpc_handlers();
@@ -142,7 +141,7 @@ apply_scgi(const std::string& arg, int type) {
     throw torrent::input_error(e.what());
   }
 
-  worker_thread->set_scgi(scgi);
+  scgi_thread::set_scgi(scgi);
   return torrent::Object();
 }
 
